@@ -8,10 +8,11 @@ This module provides a toolkit for Monte Carlo integration.
 
     mcquad   -- Integration over a uniformly-sampled hypercube.
     mcimport -- Integration over points distributed according to a particular pdf.
+    mcmiser  -- Integration over a hypercube using MISER algorithm.
     integrate_from_points -- Integration of a function over specific points.
 """
 
-__version__ = "0.1.5"
+__version__ = "0.2"
 
 try:
     __SKMONACO_SETUP__
@@ -23,6 +24,7 @@ if not __SKMONACO_SETUP__ :
     from .uniform import * 
     from .importance import *
     from .from_pts import *
+    from .miser import *
 
     from numpy.testing import Tester
     test = Tester().test
